@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: a34a7396b4e152fb5146d06f602cc2d498c1de51 $
+# $Id: 9e59ed2c7747436de991759e586185a994b021c0 $
 
 longusage() {
   echo "Gentoo Linux Genkernel ${GK_V}"
@@ -243,7 +243,7 @@ longusage() {
   echo "	--compress-initrd	Deprecated alias for --compress-initramfs"
   echo "	--no-compress-initrd	Deprecated alias for --no-compress-initramfs"
   echo "	--compress-initramfs-type=<arg>"
-  echo "				Compression type for initramfs (best, xz, lzma, bzip2, gzip, lzop)"
+  echo "				Compression type for initramfs (best, xz, lzma, bzip2, gzip, lzop, lz4)"
   echo "	--strip=(all|kernel|modules|none)"
   echo "				Strip debug symbols from none, all, installed kernel (obsolete) or"
   echo "				modules (default)"
