@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: d055b249334f8691f89381ad7bba087b39b0473f $
+# $Id: 651bfbfa9a0c8ecbf2c28c7a07c75cb4eca42ea4 $
 
 COPY_BINARIES=false
 CPIO_ARGS="--quiet --null -o -H newc --owner root:root --force-local"
@@ -135,11 +135,6 @@ copy_system_binaries() {
 			print_info 5 "System binary dirname set to '${base_dir}'."
 		fi
 
-		if LC_ALL=C "${LDDTREE_COMMAND}" "${binary}" 2>&1 | fgrep -q 'not found'
-		then
-			gen_die "$(get_useful_function_stack)System binary '${binary}' is linked to missing libraries and may need to be re-built!"
-		fi
-
 		local is_first=1
 		while IFS= read -r -u 3 binary_dependency
 		do
@@ -1185,6 +1180,12 @@ append_dropbear() {
 				missing_ssh_host_keys=yes
 			fi
 
+			if [ ! -f "/etc/ssh/ssh_host_ed25519_key" ]
+			then
+				print_info 3 "$(get_indent 2)${PN}: >> SSH host key '/etc/ssh/ssh_host_ed25519_key' is missing!"
+				missing_ssh_host_keys=yes
+			fi
+
 			if isTrue "${missing_ssh_host_keys}"
 			then
 				# Should only happen when installing a new system ...
@@ -1195,6 +1196,7 @@ append_dropbear() {
 
 		local -a required_dropbear_host_keys=(
 			/etc/dropbear/dropbear_ecdsa_host_key
+			/etc/dropbear/dropbear_ed25519_host_key
 			/etc/dropbear/dropbear_rsa_host_key
 		)
 
@@ -1223,6 +1225,12 @@ append_dropbear() {
 				then
 					print_info 1 "$(get_indent 2)${PN}: >> Dropbear host key '${required_key}' exists but is older than '/etc/ssh/ssh_host_ecdsa_key'; Removing to force update due to --ssh-host-key=create-from-host ..."
 					rm "${required_key}" || gen_die "Failed to remove outdated '${required_key}' file!"
+				elif [[ "${SSH_HOST_KEYS}" == 'create-from-host' ]] \
+					&& [[ "${required_key}" == *_ed25519_* ]] \
+					&& [[ "${required_key}" -ot "/etc/ssh/ssh_host_ed25519_key" ]]
+				then
+					print_info 1 "$(get_indent 2)${PN}: >> Dropbear host key '${required_key}' exists but is older than '/etc/ssh/ssh_host_ed25519_key'; Removing to force update due to --ssh-host-key=create-from-host ..."
+					rm "${required_key}" || gen_die "Failed to remove outdated '${required_key}' file!"
 				else
 					print_info 3 "$(get_indent 2)${PN}: >> Dropbear host key '${required_key}' exists!"
 					unset required_dropbear_host_keys[${i}]
@@ -1244,8 +1252,8 @@ append_dropbear() {
 			then
 				print_info 3 "$(get_indent 2)${PN}: >> Will use existing '${dropbear_command}' program from path to create missing keys ..."
 			else
-				local error_msg="Need to generate '${required_host_keys[*]}' but '${dropbear_command}'"
-				error_msg=" program is missing. Please install net-misc/dropbear and re-run genkernel!"
+				local error_msg="Need to generate '${required_dropbear_host_keys[*]}' but '${dropbear_command}'"
+				error_msg+=" program is missing. Please install net-misc/dropbear and re-run genkernel!"
 				gen_die "${error_msg}"
 			fi
 
@@ -1266,8 +1274,8 @@ append_dropbear() {
 			print_info 2 "$(get_indent 2)${PN}: >> Using existing dropbear host keys from /etc/dropbear ..."
 		fi
 
-		cp -aL --target-directory "${initramfs_dropbear_dir}" /etc/dropbear/{dropbear_rsa_host_key,dropbear_ecdsa_host_key} \
-			|| gen_die "Failed to copy '/etc/dropbear/{dropbear_rsa_host_key,dropbear_ecdsa_host_key}'"
+		cp -aL --target-directory "${initramfs_dropbear_dir}" /etc/dropbear/dropbear_{rsa,ecdsa,ed25519}_host_key \
+			|| gen_die "Failed to copy '/etc/dropbear/dropbear_{rsa,ecdsa,ed25519}_host_key'"
 
 		# Try to show embedded dropbear host key details for security reasons.
 		# We do it that complicated to get common used formats.
